# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Mysql"
"""
  * @File    :   Mysql.py
  * @Time    :   2023/04/26 02:33:36
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, Ship of Ocean
  * @Desc    :   None
"""


class Mysql:
    def create(self, *args, **kwargs):
        # import mysql.connector

        # mydb = mysql.connector.connect(
        #   host="localhost",
        #   user="yourusername",
        #   password="yourpassword",
        #   database="mydatabase"
        # )

        # mycursor = mydb.cursor()

        # mycursor.execute("SHOW TABLES")

        # for x in mycursor:
        #   print(x)
        pass
