# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Section"
"""
  * @File    :   Section.py
  * @Time    :   2023/04/26 02:04:35
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, Ship of Ocean
  * @Desc    :   None
"""


from xy_web_settings.Section.Section import Section as xyWebSettingsSection


class Section(xyWebSettingsSection):
    pass
